summaryrefslogtreecommitdiff
path: root/tools/ci/scripts/runtest.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/ci/scripts/runtest.sh')
-rwxr-xr-xtools/ci/scripts/runtest.sh30
1 files changed, 15 insertions, 15 deletions
diff --git a/tools/ci/scripts/runtest.sh b/tools/ci/scripts/runtest.sh
index e629fc514..523bd4b41 100755
--- a/tools/ci/scripts/runtest.sh
+++ b/tools/ci/scripts/runtest.sh
@@ -6,19 +6,19 @@ function check_is_run {
echo "Error: process look like crashed"
cat logs/run.log
echo "Run with gdb"
- cp ./src/manaplus ./logs/
+ cp ./src/manaverse ./logs/
cp -r core* ./logs/
sleep 10
COREFILE=$(find . -maxdepth 1 -name "core*" | head -n 1)
if [[ -f "$COREFILE" ]]; then
- gdb -c "$COREFILE" ./src/manaplus -ex "thread apply all bt" -ex "set pagination 0" -batch
+ gdb -c "$COREFILE" ./src/manaverse -ex "thread apply all bt" -ex "set pagination 0" -batch
fi
exit 1
fi
}
function check_assert {
- grep -A 20 "Assert:" "${HOME}/.local/share/mana/manaplus.log"
+ grep -A 20 "Assert:" "${HOME}/.local/share/manaverse/manaverse.log"
if [ "$?" == 0 ]; then
echo "Assert found in log"
exit 1
@@ -31,9 +31,9 @@ function wait_for_servers_list {
echo "wait for servers list ${n}"
check_is_run
# check here
- grep "Skipping servers list update" "${HOME}/.local/share/mana/manaplus.log" && return
- grep "Servers list updated" "${HOME}/.local/share/mana/manaplus.log" && return
- grep "Error: servers list updating error" "${HOME}/.local/share/mana/manaplus.log"
+ grep "Skipping servers list update" "${HOME}/.local/share/manaverse/manaverse.log" && return
+ grep "Servers list updated" "${HOME}/.local/share/manaverse/manaverse.log" && return
+ grep "Error: servers list updating error" "${HOME}/.local/share/manaverse/manaverse.log"
if [ "$?" == 0 ]; then
echo "Servers list downloading error"
exit 1
@@ -50,9 +50,9 @@ function wait_for_servers_list {
}
function run {
- ./src/manaplus --hide-cursor --enable-ipc --renderer=0 >logs/run.log 2>&1 &
+ ./src/manaverse --hide-cursor --enable-ipc --renderer=0 >logs/run.log 2>&1 &
export PID=$!
- echo "manaplus PID: ${PID}"
+ echo "manaverse PID: ${PID}"
sleep 15
echo "pause after run"
wait_for_servers_list
@@ -95,16 +95,16 @@ function send_command {
}
function check_exists {
- if [ ! -f "logs/home/Desktop/ManaPlus/$1" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$1" ]; then
sleep 7
- if [ ! -f "logs/home/Desktop/ManaPlus/$1" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$1" ]; then
echo "Error: image $1 not exists"
exit 1
fi
fi
- if [ ! -f "logs/home/Desktop/ManaPlus/$2" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$2" ]; then
sleep 7
- if [ ! -f "logs/home/Desktop/ManaPlus/$2" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$2" ]; then
echo "Error: image $2 not exists"
exit 1
fi
@@ -113,7 +113,7 @@ function check_exists {
function imagesdiff {
check_exists "$1" "$2"
- diff "logs/home/Desktop/ManaPlus/$1" "logs/home/Desktop/ManaPlus/$2"
+ diff "logs/home/Desktop/ManaVerse/$1" "logs/home/Desktop/ManaVerse/$2"
if [ "$?" == 0 ]; then
echo "Error: images '$1' and '$2' is same."
exit 1
@@ -122,7 +122,7 @@ function imagesdiff {
function imagessame {
check_exists "$1" "$2"
- diff "logs/home/Desktop/ManaPlus/$1" "logs/home/Desktop/ManaPlus/$2"
+ diff "logs/home/Desktop/ManaVerse/$1" "logs/home/Desktop/ManaVerse/$2"
if [ "$?" != 0 ]; then
echo "Error: images '$1' and '$2' is different."
exit 1
@@ -233,7 +233,7 @@ imagesdiff new_server.png about.png
send_command "/sendmousekey 500 20 1"
send_command "/screenshot about.png"
# open about manaplus page
send_command "/sendmousekey 300 ${ABOUTYOFFSET} 1"
send_command "/screenshot about2.png"
imagesdiff about.png about2.png
@@ -233,7 +233,7 @@ imagesdiff new_server.png about.png
send_command "/sendmousekey 500 20 1"
send_command "/screenshot about.png"
-# open about manaplus page
+# open about manaverse page
send_command "/sendmousekey 300 ${ABOUTYOFFSET} 1"
send_command "/screenshot about2.png"